Struct fend_core::FendResult
source · pub struct FendResult { /* private fields */ }Expand description
This contains the result of a computation.
Implementations
sourceimpl FendResult
impl FendResult
sourcepub fn get_main_result(&self) -> &str
pub fn get_main_result(&self) -> &str
This retrieves the main result of the computation.
sourcepub fn get_main_result_spans(&self) -> impl Iterator<Item = SpanRef<'_>>
pub fn get_main_result_spans(&self) -> impl Iterator<Item = SpanRef<'_>>
This retrieves the main result as a list of spans, which is useful for colored output.
sourcepub fn is_unit_type(&self) -> bool
pub fn is_unit_type(&self) -> bool
Returns whether or not the result is the () type. It can sometimes
be useful to hide these values.